<?php

namespace Drupal\syncloud\Service;

use Drupal\user\Entity\User;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\ClientException;
use GuzzleHttp\Exception\GuzzleException;
use GuzzleHttp\Exception\RequestException;
use GuzzleHttp\Exception\ConnectException;
/**
 * Class Connector.
 */
class Queue {
  /**
   * Init funciton.
   */
  public function __construct() {
    $this->syn_storage = \Drupal::entityTypeManager()->getStorage('syn');
  }

  /**
   * Hook.
   */
  public function guzzlePushQueue() {
    $host = \Drupal::request()->getSchemeAndHttpHost();
    $client = new Client([
      'base_uri' => $host,
      'timeout'  => 0.1,
    ]);
    try {
      $response = $client->get("$host/syncloud/queue");
      $message = $response->getStatusCode();
    } catch (ConnectException $e) {
      $message = 'ConnectException ' . $e->getMessage();
    } catch (RequestException $e) {
      $message = 'RequestException ' . $e->getMessage();
    } catch (ClientException $e) {
      $message = 'ClientException ' . $e->getMessage();
    } catch (GuzzleException $e) {
      $message = 'GuzzleException ' . $e->getMessage();
    }
    return $message;
  }

  /**
   * Push entity to queue.
   */
  public function queuePush(int $id, $syn_id) {
    $queue = \Drupal::queue('syncloud_queue');
    $queue->createQueue();
    $queue->createItem([
      'id' => $id,
      'syn_id' => $syn_id,
    ]);
  }


  /**
   * Process queue.
   */
  public function queueProcess() {
    $end = time() + 30;
    $queue = \Drupal::queue('syncloud_queue');
    while (time() < $end && ($item = $queue->claimItem())) {
      $syn = $this->syn_storage->load($item->data['syn_id']);
      $storage = \Drupal::entityTypeManager()->getStorage($syn->type->value);
      $entity = $storage->load($item->data['id']);
      $config =  \Drupal::configFactory()->get('syncloud.settings');
      if ($config->get('telegram-int')) {
        $uuid = \Drupal::state()->get('syncloud.uuid');
        $msg = [
          'ip' => $syn->ip->value,
          'type' => $syn->type->value,
          'host' => $syn->host->value,
          'matomo' => $syn->syn_id->value,
          'url' => $syn->url->value,
        ];
        foreach ($entity->getFields() as $name => $field) {
          $msg['message--' . $name] = $field->getString();
        }
        \Drupal::service('syncloud.mqtt')->run()->publish("\$telega/syncloud/$uuid/event/contact-message", json_encode($msg));
      }
      $queue->deleteItem($item);
    }
  }
}
